# toptips

* 作者：liuduan
* 邮箱：liuduan.05.05@163.com
* 版本：**`0.1.8`**

## 介绍

_吸顶提示信息条_

---

## 安装

`lm-*` 组件使用 `npm` 进行管理，命名空间统一为 `lm-`，请使用以下命令进行组件安装。

```
npm i lm-toptips --save
```

- 如果你还没有安装 `npm`，可通过以下方式进行 [安装](https://nodejs.org/en/download/)。
- 安装cnpm `npm install -g cnpm --registry=https://registry.npm.taobao.org`

---

## 使用

### 样例文档

```javascript
    export default class App extends Component {

        constructor(args, context) {
            super(args);

            this.state = {
                show: true
            };

            this.onClick = this.onClick.bind(this);
            this.showTips = this.showTips.bind(this);
        }

        _testData = {
            test0: '珍爱信用，如实填写，我们承诺对您的信息绝对保密',
            test1: '该密码可用于申请或提现',
            test2: '该密码可用于申请或提现该密码可用于申请或体现该密码可用于申请或体现该密码可用于申请或提现',
            test3: <div>欢迎拨打<a>58同城客户服务热线：58585858</a></div>,
            test4: [
                '珍爱信用，如实填写，我们承诺对您的信息绝对保密',
                '该密码可用于申请或体现',
                '该密码可用于申请或体现该密码可用于申请或体现该密码可用于申请或体现该密码可用于申请或体现',
                <div key={0}>欢迎拨打<a>58同城客户服务热线：58585858</a>需要设置key属性</div>,
                <p key={1}>该密码可用于申请或体现该密码可用于申请或体现该密码可用于申请或体现该密码可用于申请或体现</p>
            ],
            test5: <p>该密码可用于申请或体现该密码可用于申请或体现该密码可用于申请或体现该密码可用于申请或体现</p>
        };

        onClick() {
            console.log('app onClick')
        }

        showTips() {
            this.setState({
                show: !this.state.show
            })
        }

        render() {
            const { test0, test1, test2, test3, test4, test5 } = this._testData;
            const icon = (
                <span>icon</span>
            )
            return (
                <section>
                    <div onClick={this.showTips}>显示 | 隐藏</div><br />
                    {/* =========== test0 ============ */}
                    {this.state.show ?
                        <Toptips
                            mode="closable"
                            marqueePropsX={{type: 'ellipsis'}}
                        >
                            {test0}
                        </Toptips>
                        : null
                    }
                    
                    <br />
                    {/* =========== test1 ============ */}
                    <Toptips
                        onClick={this.onClick}
                        mode="link"
                        linkText="点击处理"
                    >
                        {test1}
                    </Toptips>

                    <br />
                    {/* =========== test2 ============ */}
                    <Toptips
                        mode="closable"
                        marqueePropsX={{type: 'ellipsis'}}
                        onClick={this.onClick}
                    >
                        {test2}
                    </Toptips>

                    <br />
                    {/* =========== test3 ============ */}
                    <Toptips icon={icon}>
                        {test3}
                    </Toptips>

                    <br />
                    {/* =========== test4 ============ */}
                    <Toptips>
                        {test4}
                    </Toptips>

                    <br />
                    {/* =========== test5 ============ */}
                    <Toptips>
                        {test5}
                    </Toptips>

                    <br />
                    {/* =========== test6 ============ */}
                    <Toptips marqueePropsX={{type: 'clip'}}>
                        {test5}
                    </Toptips>

                    <br />
                    {/* =========== test7 ============ */}
                    <Toptips marqueePropsX={{type: 'break'}}>
                        {test5}
                    </Toptips>

                    <br />
                    {/* =========== test8 ============ */}
                    <Toptips marqueePropsY={{type: 'nonauto'}}>
                        {test4}
                    </Toptips>

                </section>
            )
        }
    }
```

### 使用
配置参数为：
- 传入`children`显示贴士信息
    ```javascript
        <Toptips>{test}</Toptips>
    ```
- 传入`icon`显示前缀图标或文本
    ```javascript
        <Toptips icon={icon}>{test}</Toptips>
    ```
-  传入`mode`显示后缀样式
    ```javascript
        // 关闭
        <Toptips mode="closable">{test}</Toptips>
        // 链接
        <Toptips mode="link">{test}</Toptips>
    ```
- 传入`linkText`显示链接文本
    ```javascript
        <Toptips mode="link" linkText="点击跳转">{test}</Toptips>
    ```
- 传入`onClick`点击事件回调函数
    ```javascript
        <Toptips mode="closable" onClick={() => console.log('click-closable')}>{test}</Toptips>
        <Toptips mode="link" onClick={() => console.log('click-link')}>{test}</Toptips>
    ```
- 传入`marqueePropsX`设置水平向文字显示状态
    ```javascript
        <Toptips marqueePropsX={{
            loop: false
        }}>{test}</Toptips>
    ```
- 传入`marqueePropsY`设置竖直向文字显示状态
    ```javascript
        <Toptips marqueePropsX={{
            loop: false,
            type: 'nonauto'
            speed: 0
        }}>{test}</Toptips>
    ```

### Toptips配置参数

| Prop | Type | Default | Description | 
| ---- |:----:|:-------:| :----------:|
| **`prefixCls`** | `String` | `"lm-toptips"` | 自定义类名前缀 |
| **`className`** | `String` | `''` | 自定义className |
| **`mode`** | `String` | `''` | 提示类型，可选 `'closable'`,`'link'` |
| **`linkText`** | `String || React.Element` | `''` | 链接文本 |
| **`icon`** | `String || React.Element` | `null` | 图标元素 |
| **`marqueePropsX`** | `Object` | `{type: "marquee", loop: true, speed: 0, startDelay: 800, endDelay: 500}` | 水平跑马灯相关属性 |
| **`marqueePropsY`** | `Object` | `{type: "marquee", loop: true, speed: 15, startDelay: 800, endDelay: 500}` | 竖直跑马灯相关属性 |
| **`onClick`** | `Function` | `() => {}` | 点击关闭或者操作区域的回调函数 |


### marqueePropsX参数属性

| Prop | Type | Default | Description | 
| ---- |:----:|:-------:|:----------:|
| **`prefixCls`** | `String` | `"lm"` | 自定义类名前缀 |
| **`className`** | `String` | `''` | 自定义className |
| **`type`** | `String` | `'marquee'` | 显示类型<br>跑马灯：`'marquee'`<br>显示...：`'ellipsis'`<br>修剪文本：`'clip'`<br>折行：`'break'` |
| **`speed`** | `Number` | `0` | 动画移动距离/每秒, 若不传或传数字0则按浏览器重绘刷新频率 |
| **`startDelay`** | `Number` | `800` | 动画单次播放开始延时时间 |
| **`endDelay`** | `Number` | `500` | 动画单次播放结束停留时间 |
| **`loop`** | `Bool` | `true` | 是否循环播放 |


### marqueePropsY参数属性

| Prop | Type | Default | Description | 
| ---- |:----:|:-------:|:----------:|
| **`prefixCls`** | `String` | `"lm"` | 自定义类名前缀 |
| **`className`** | `String` | `''` | 自定义className |
| **`type`** | `String` | `'marquee'` | 滚动类型<br>自动：`'marquee'`<br>手动：`'nonauto'` |
| **`speed`** | `Number` | `15` | 动画移动距离/每秒, 若不传或传数字0则按浏览器重绘刷新频率 |
| **`startDelay`** | `Number` | `800` | 动画单次播放开始延时时间 |
| **`endDelay`** | `Number` | `500` | 动画单次播放结束停留时间 |
| **`loop`** | `Bool` | `true` | 是否循环播放 |

---

## 注意事项

- 当期望多列滚动显示时，`children`属性类型应为`Array`，且如果Array中元素如果为`DOM`，必须设置`key`属性，示例：
    ```javascript
        testList: [
                '珍爱信用，如实填写，我们承诺对您的信息绝对保密',
                '该密码可用于申请或体现',
                <div key={0}>欢迎拨打<a>58同城客户服务热线：58585858</a>需要设置key属性</div>,
                <p key={1}>该密码可用于申请或体现该密码可用于申请或体现该密码可用于申请或体现该密码可用于申请或体现</p>
        ]
    ```

---

## 开发调试

进入项目目录后，使用 `node` 命令启动服务

```
npm run start
```

打包发布可通过 `node` 命令执行

```
npm run build
npm publish
```

---

## 相关资料

* [lm 组件开发规范](http://)

---

## Changelog

### 0.1.5
1. 样式控制有style改为class
1. 修改github地址

### 0.1.7
1. 兼容屏幕尺寸变化及旋转屏幕显示效果
1. 更新动画滚动速度默认为按浏览器刷新频率，若设置speed可按自定义速度滚动

### 0.1.8
1. MarqueeX、MarqueeY组件在卸载时移除监听事件

---
