/**
 * Created by liuduan<liuduan.05.05@163.com>.
 * ComponentName MarqueeY
 * Desc 跑马灯显示列表-垂直方向
 * GroupName lm-component
 */
import React, { Component } from 'react';
import ReactDOM from 'react-dom';
import PropTypes from 'prop-types';

import classNames from 'classnames';
import './index.scss';

export default class MarqueeY extends Component {

    static propTypes = {
        prefixCls: PropTypes.string,
        className: PropTypes.string,
        type: PropTypes.string,
        speed: PropTypes.number,
        startDelay: PropTypes.number,
        endDelay: PropTypes.number,
        loop: PropTypes.bool
    };

    static defaultProps = {
        prefixCls: 'lm',
        className: '',
        /* ===== 计时器相关属性 ===== */
        type: 'marquee',    // 显示模式：marquee-跑马灯 | nonauto-overflow-y: auto
        speed: 15,          // 动画移动距离/每秒
        startDelay: 800,    // 动画单次播放开始延时时间
        endDelay: 500,      // 动画单次播放结束停留时间
        loop: true          // 是否循环播放
    };

    /* ======= 实例属性 ======= */
    state = {
        overflowHeighe: 0,  // 文字超出wrap部分宽度
        animatedHeight: 0   // 文字移动的距离
    };

    _marqueeTimer; // 计时器函数

    componentDidMount() {
        this._measureList(this._startAnimation);
        // 监听尺寸变化
        window.addEventListener('resize', this.resetHandle.bind(this));
    }

    componentWillReceiveProps(nextProps) {
        if ('children' in nextProps) this.resetHandle();
    }
    
    componentWillUnmount() {
        window.removeEventListener('resize', this.resetHandle.bind(this));
        if (this._marqueeTimer) this._marqueeTimer = clearTimeout(this._marqueeTimer);
    }

    // 重置动画
    resetHandle() {
        this.setState({
            animatedHeight: 0
        }, () => {
            if (this._marqueeTimer) this._marqueeTimer = clearTimeout(this._marqueeTimer);
            this._measureList(this._startAnimation);
        });
    }

    render() {

        const { children, className, prefixCls, type, speed, startDelay, endDelay, loop, ...others } = this.props;
        const { animatedHeight } = this.state;

        const cls = classNames('lm-marqueeY', `${prefixCls}-marqueeY`, className);
        let style={}, listStyle = {};
        style = {
            overflowY: type === 'marquee' ? 'hidden' : 'auto'
        };
        listStyle = {
            position: 'relative',
            bottom: animatedHeight
        };

        return (
            <div className={cls} {...others} style={style}>
                <div ref={el => this.tiplist = el} style={listStyle}>
                    {children} 
                </div>
            </div>
        )
    }

    /* 私有方法：计算list超出marquee容器范围的宽度 */
    _measureList(cb) {
        const wrap = ReactDOM.findDOMNode(this);
        const list = this.tiplist;
        if (wrap && list) {
            // 获取marquee容器宽度
            const wrapHeight = wrap.offsetHeight;
            // 获取文字宽度
            const listHeight = list.offsetHeight;
            // 获取文字超出容器部分宽度
            const overflowHeight = listHeight - wrapHeight;
            this.setState({
                overflowHeight
            }, cb.bind(this));
        }
    }

    /* 私有方法：计时器-滚动计算 */
    _startAnimation() {
        if (this._marqueeTimer) {
            clearTimeout(this._marqueeTimer);
        }
        const { type, speed, startDelay, endDelay, loop } = this.props;
        let timeout;
        if (speed) timeout = 1 / speed * 1000;

        const animate = () => {
            let { overflowHeight, animatedHeight } = this.state;
            animatedHeight++;
            const isRoundOver = animatedHeight > overflowHeight;
            // 判断单次播放完毕，若播放完毕再判断是否需要循环播放
            if (isRoundOver) {
                if (loop) {
                    // 开启循环播放函数
                    animatedHeight = 0;
                    this._marqueeTimer = setTimeout(() => {
                        this.setState({
                            animatedHeight,
                        }, () => {
                            this._marqueeTimer = setTimeout(animate, startDelay);
                        });
                    }, endDelay);
                } else {
                    return;
                }
            } else {
                // 播放过程动画函数
                this.setState({
                    animatedHeight,
                }, () => {
                    if (timeout) {
                        this._marqueeTimer = setTimeout(animate, timeout);
                    } else {
                        window.requestAnimationFrame(animate);
                    }
                });
            }
        };

        // 如果文字内容超出wrap, 开启首次滚动动画
        if (this.state.overflowHeight > 0 && type === 'marquee') {
            this._marqueeTimer = setTimeout(animate, startDelay);
        }
    }

}
