/**
 * Created by liuduan<liuduan.05.05@163.com>.
 * ComponentName Toptips
 * Desc 吸顶提示信息条
 * GroupName lm-component
 */
import React, { Component } from 'react'
import PropTypes from 'prop-types'

import classNames from 'classnames';
import './index.scss';

import MarqueeX from './MarqueeX';
import MarqueeY from './MarqueeY';

export default class Toptips extends Component {

    static propTypes = {
        prefixCls: PropTypes.string,
        className: PropTypes.string,
        mode: PropTypes.string,
        linkText: PropTypes.oneOfType([
            PropTypes.string, PropTypes.element
        ]),
        icon: PropTypes.oneOfType([
            PropTypes.string, PropTypes.element
        ]),
        marqueePropsX: PropTypes.object,
        marqueePropsY: PropTypes.object,
        onClick: PropTypes.func
    };

    static defaultProps = {
        prefixCls: 'lm-toptips',
        className: '',
        mode: '',
        linkText: '',
        icon: null,
        marqueePropsX: {},
        marqueePropsY: {},
        onClick() { }
    };

    constructor(props) {
        super(props);

        this.state = {
            show: true,
            reset: false
        }

        this.onClick = this.onClick.bind(this);
    }

    onClick() {
        const { onClick, mode } = this.props;
        // 预留钩子
        if (onClick) onClick();
        // 若可关闭的内部实现关闭
        if (mode === 'closable') {
            this.setState({
                show: !this.state.show
            });
        }
    }
    /* 根据需求渲染后缀 */
    renderSuffix() {
        const { mode, prefixCls, linkText } = this.props;
        let suffix = null;

        switch (mode) {
            case 'closable':
                suffix = (
                    <div className={`${prefixCls}-suffix`} onClick={this.onClick}>
                        <span className={`${prefixCls}-suffix-close`}></span>
                    </div>
                )
                break;
            case 'link':
                suffix = (
                    <div className={`${prefixCls}-suffix`}>
                        <span className={`${prefixCls}-suffix-link`}>{linkText}</span>
                    </div>
                )
                break;
            default:
                break;
        }

        return suffix;
    }

    /* 渲染元素 */
    renderTips() {
        const { children, prefixCls, marqueePropsX } = this.props;
        const tiplist = React.Children.toArray(children);
        let showType = {};
        // 若是上下滚动显示则折行处理
        if (tiplist.length > 1) {
            showType['type'] = 'break';
        } else {
            showType = {};
        }
        return tiplist.map((item, index) => (
            <MarqueeX
                { ...{...marqueePropsX, ...showType}}
                key={index}
                prefixCls={prefixCls}
                reset={this.state.reset}
            >
                {item}
            </MarqueeX>
        ));
    }

    render() {

        const { mode, icon, onClick, children, className, prefixCls, linkText, marqueePropsX, marqueePropsY, ...others } = this.props;
        const wrapCls = classNames(prefixCls, className);

        // 处理tip条是否可点击
        let extraProps = {};
        if (mode !== 'closable') extraProps.onClick = onClick;

        return this.state.show ? (
            <div className={wrapCls} {...extraProps} {...others}>

                {/* === icon === */}
                {icon && <div className={`${prefixCls}-icon`}>{icon}</div>}

                {/* === content === */}
                <MarqueeY className={`${prefixCls}-main`} {...marqueePropsY}>
                    {this.renderTips()}
                </MarqueeY>

                {/* === suffix === */}
                {this.renderSuffix()}

            </div>
        ) : null;
    }

}
